Installing — flask-peewee v0.1.0 documentation

### Navigation

- index
- next |
- previous |
- flask-peewee v0.1.0 documentation »

# Installing

flask-peewee can be installed very easily using pip.

    pip install flask-peewee

If you do not have the dependencies installed already, pip will install them for you, but for reference they are:

- flask
- peewee
- wtforms
- wtforms-peewee
- python 2.5 or greater

## Using git

If you want to run the very latest, feel free to pull down the repo from github and install by hand.

    git clone https://github.com/coleifer/flask-peewee.git
    cd flask-peewee
    python setup.py install

You can run the tests using the test-runner:

    python setup.py test

### Navigation

- index
- next |
- previous |
- flask-peewee v0.1.0 documentation »